@@ -533,10 +533,36 @@ nlive.pmms <- function(dataset, ID, outcome, time, var.all = NULL,
       n2_group0 = tab_traj$slope2[1]
       n3_group0 = tab_traj$changepoint[1]
 
+      e  = tab_traj$transition[1]
+      ## GROUP OF REFENCE (val == 0) ##
+      lambda = n0_group0 + n2_group0*(n3_group0+e/2) - n1_group0*(n3_group0 + e/2)
+      tab_traj$I1 = as.numeric(tab_traj$time <= tab_traj$changepoint)
+      tab_traj$I2 = as.numeric(tab_traj$time >  tab_traj$changepoint & tab_traj$time < tab_traj$changepoint + 2)
+      tab_traj$I3 = as.numeric(tab_traj$time >= tab_traj$changepoint + 2)
+
+      # system of 4 linear equations with 4 unknown parameters
+      A = matrix(c(n3_group0^3, n3_group0^2, n3_group0, 1,
+                   (n3_group0+e)^3, (n3_group0+e)^2, (n3_group0+e), 1,
+                   2*(n3_group0^2), 2*n3_group0, 1, 0,
+                   2*((n3_group0+e)^2), 2*(n3_group0+e), 1, 0), ncol=4, byrow=T)
+      B = matrix(c(n0_group0+n2_group0*(n3_group0+e/2)-n1_group0*(n3_group0+e/2)+n1_group0*n3_group0,
+                   n0_group0+n2_group0*(n3_group0+e),
+                   n1_group0,
+                   n2_group0))
+      mat = solve(A) %*% B
+
+      tab_traj$traj_PMM_group0 =
+        tab_traj$I1*(lambda+n1_group0*tab_traj$time)+
+        tab_traj$I2*(mat[1]*(tab_traj$time^3) + mat[2]*(tab_traj$time^2) + mat[3]*tab_traj$time + mat[4]) +
+        tab_traj$I3*(n0_group0+n2_group0*tab_traj$time)
+
+
+
+
       ## GROUP OF REFENCE (val == 1)
       pos_raw = which(traj.marg.group == rownames(mat_predictor))
       ##
-      tab_traj = data.frame(time = seq(min_plot, max_plot, 0.1), transition = 2)
+      #tab_traj = data.frame(time = seq(min_plot, max_plot, 0.1), transition = 2)
       ##
       tab_traj$last.level  = coef.PMM[1] + coef.PMM[1+pos_raw]*mat_predictor[pos_raw,1]
       tab_traj$slope1      = coef.PMM[1*length(var.all2)+length(var.last.level2) + 2] + coef.PMM[1*length(var.all2)+length(var.last.level2) + 2 + pos_raw]*mat_predictor[pos_raw,2]
@@ -559,28 +585,9 @@ nlive.pmms <- function(dataset, ID, outcome, time, var.all = NULL,
       n3_group1 = tab_traj$changepoint[1]
 
 
-        e  = tab_traj$transition[1]
-        ## GROUP OF REFENCE (val == 0) ##
-        lambda = n0_group0 + n2_group0*(n3_group0+e/2) - n1_group0*(n3_group0 + e/2)
-        tab_traj$I1 = as.numeric(tab_traj$time <= tab_traj$changepoint)
-        tab_traj$I2 = as.numeric(tab_traj$time >  tab_traj$changepoint & tab_traj$time < tab_traj$changepoint + 2)
-        tab_traj$I3 = as.numeric(tab_traj$time >= tab_traj$changepoint + 2)
 
-        # system of 4 linear equations with 4 unknown parameters
-        A = matrix(c(n3_group0^3, n3_group0^2, n3_group0, 1,
-                     (n3_group0+e)^3, (n3_group0+e)^2, (n3_group0+e), 1,
-                     2*(n3_group0^2), 2*n3_group0, 1, 0,
-                     2*((n3_group0+e)^2), 2*(n3_group0+e), 1, 0), ncol=4, byrow=T)
-        B = matrix(c(n0_group0+n2_group0*(n3_group0+e/2)-n1_group0*(n3_group0+e/2)+n1_group0*n3_group0,
-                     n0_group0+n2_group0*(n3_group0+e),
-                     n1_group0,
-                     n2_group0))
-        mat = solve(A) %*% B
 
-        tab_traj$traj_PMM_group0 =
-          tab_traj$I1*(lambda+n1_group0*tab_traj$time)+
-          tab_traj$I2*(mat[1]*(tab_traj$time^3) + mat[2]*(tab_traj$time^2) + mat[3]*tab_traj$time + mat[4]) +
-          tab_traj$I3*(n0_group0+n2_group0*tab_traj$time)
+
 
         ## SECOND GROUP (val == 1) ##
         lambda = n0_group1 + n2_group1*(n3_group1+e/2) - n1_group1*(n3_group1 + e/2)
